==> mfire-1.2rc1.tar.gz: mfire-1.2rc1/mfire/composite/geos.py <==
"""
    Module d'interprétation de la configuration des geos
"""

from typing import List, Union, Optional

import xarray as xr
from pydantic import validator

from mfire.settings import get_logger, Settings, ALT_MIN, ALT_MAX
from mfire.utils.xr_utils import MaskLoader
from mfire.composite.base import BaseComposite


# Logging
LOGGER = get_logger(name="geos.mod", bind="geos")


class GeoComposite(BaseComposite):
    """Création d'un objet Geo contenant la configuration des périodes
    de la tâche de production promethee

    Args:
        baseModel : modèle de la librairie pydantic

    Returns:
        baseModel : objet Geo
    """

    file: str
    mask_id: Optional[Union[List[str], str]]
    grid_name: Optional[str]

    def _compute(self) -> xr.DataArray:
        return MaskLoader(filename=self.file, grid_name=self.grid_name).load(
            ids_list=self.mask_id
        )


class AltitudeComposite(BaseComposite):
    """Création d'un objet Field contenant la configuration des champs
    de la tâche de production promethee

    Args:
        baseModel : modèle de la librairie pydantic

    Returns:
        baseModel : objet Field
    """

    filename: str = Settings().altitudes_filename
    grid_name: Optional[str]
    alt_min: Optional[int] = ALT_MIN
    alt_max: Optional[int] = ALT_MAX

    @validator("alt_min")
    def init_alt_min(cls, v: int) -> int:
        if v is None:
            return ALT_MIN
        return v

    @validator("alt_max")
    def init_alt_max(cls, v: int) -> int:
        if v is None:
            return ALT_MAX
        return v

    @validator("filename")
    def init_filename(cls, v: str) -> str:
        if v is None:
            return Settings().altitudes_filename
        return v

    def _compute(self) -> xr.DataArray:
        # on load le fichier d'altitude
        field_da = MaskLoader(filename=self.filename, grid_name=self.grid_name).load()
        # on applique les restrictions d'alt min et alt max
        return field_da.where(field_da >= self.alt_min).where(field_da <= self.alt_max)

==> mfire-2.0.dev8.tar.gz: mfire-2.0.dev8/mfire/composite/geos.py <==
"""
    Module d'interprétation de la configuration des geos
"""

from __future__ import annotations
from typing import List, Union, Optional
from pathlib import Path

import xarray as xr
from pydantic import validator

from mfire.settings import get_logger, Settings, ALT_MIN, ALT_MAX
from mfire.utils.xr_utils import MaskLoader, ArrayLoader
from mfire.composite.base import BaseComposite


# Logging
LOGGER = get_logger(name="geos.mod", bind="geos")


class GeoComposite(BaseComposite):
    """Création d'un objet Geo contenant la configuration des périodes
    de la tâche de production promethee

    Args:
        baseModel : modèle de la librairie pydantic

    Returns:
        baseModel : objet Geo
    """

    file: Path
    mask_id: Optional[Union[List[str], str]]
    grid_name: Optional[str]

    def _compute(self) -> xr.DataArray:
        return MaskLoader(filename=self.file, grid_name=self.grid_name).load(
            ids_list=self.mask_id
        )


class AltitudeComposite(BaseComposite):
    """Création d'un objet Field contenant la configuration des champs
    de la tâche de production promethee

    Args:
        baseModel : modèle de la librairie pydantic

    Returns:
        baseModel : objet Field
    """

    filename: Path
    alt_min: Optional[int] = ALT_MIN
    alt_max: Optional[int] = ALT_MAX

    @validator("alt_min")
    def init_alt_min(cls, v: int) -> int:
        if v is None:
            return ALT_MIN
        return v

    @validator("alt_max")
    def init_alt_max(cls, v: int) -> int:
        if v is None:
            return ALT_MAX
        return v

    @validator("filename")
    def init_filename(cls, v: Path) -> Path:
        filename = Path(v)
        if not filename.is_file():
            raise FileNotFoundError(f"No such file {v}.")
        return filename

    def _compute(self) -> xr.DataArray:
        # on load le fichier d'altitude
        field_da = ArrayLoader(filename=self.filename).load()
        # on applique les restrictions d'alt min et alt max
        return field_da.where(field_da >= self.alt_min).where(field_da <= self.alt_max)

    @classmethod
    def from_grid_name(
        cls,
        grid_name: str,
        alt_min: Optional[int] = None,
        alt_max: Optional[int] = None,
    ) -> AltitudeComposite:
        return cls(
            filename=Path(Settings().altitudes_dirname) / f"{grid_name}.nc",
            alt_min=alt_min,
            alt_max=alt_max,
        )
